Tutorials(Advanced)
-------------------

This document lists some advanced tutorials. These tutorials require sufficiently good knowledge about mechanics concepts. 
These tutorials are in the form of IPython notebooks.

Tutorials:

  - `N Pendulum example`_
  

.. _`N Pendulum example`: http://nbviewer.ipython.org/github/pydy/pydy/blob/master/examples/npendulum/n-pendulum-control.ipynb

